/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: convtolower.c,v 1.2 2010/03/03 16:00:38 tokai Exp $

    Desc: ConvToLower() - Stub for the Language tolower() function.
    Lang: english
*/
#include <exec/types.h>
#include "locale_intern.h"
#include <aros/asmcall.h>

#define	DEBUG_CONVTOLOWER(x)	;

/*****************************************************************************

    NAME */
#include <proto/locale.h>

    AROS_LH2(ULONG, ConvToLower,

/*  SYNOPSIS */
	AROS_LHA(struct Locale *, locale, A0),
	AROS_LHA(ULONG          , character, D0),

/*  LOCATION */
	struct LocaleBase *, LocaleBase, 8, Locale)

/* ---- locale.library/ConvToLower
 *
 *   NAME
 *        ConvToLover -- convert a character to lower case
 *
 *   FUNCTION
 *        This function determine if the character supplied is upper case,
 *        and if it is, the character will be converted to lower case.
 *        Otherwise, the original character will be returned.
 *
 *   INPUTS
 *        locale      - The Locale to use for this conversion.
 *        character   - The character to convert to lower case.
 *
 *   RESULT
 *        The possibly converted character.
 *  
 *   NOTES
 *        This function requires a full 32-bit character in order to
 *        support future multi-byte character sets.
 *
 * ----
 *
 *   HISTORY
 *   27-11-96    digulla automatically created from
 *               locale_lib.fd and clib/locale_protos.h
 */
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct LocaleBase *,LocaleBase)
    ULONG	retval;

    DEBUG_CONVTOLOWER(dprintf("ConvToLower: locale 0x%lx char 0x%lx\n",
			locale,
			character));

    DEBUG_CONVTOLOWER(dprintf("ConvToLower: func 0x%lx\n",
			IntL(locale)->il_LanguageFunctions[LF_CONVTOLOWER]));

#ifdef AROS_CALL1
    retval = AROS_CALL1(ULONG, IntL(locale)->il_LanguageFunctions[LF_CONVTOLOWER],
	AROS_LCA(ULONG, character, D0),
	struct LocaleBase *, LocaleBase);
#else
    retval = AROS_UFC2(ULONG, IntL(locale)->il_LanguageFunctions[LF_CONVTOLOWER],
	AROS_UFCA(ULONG, character, D0),
	AROS_UFCA(struct LocaleBase *, LocaleBase, A6));
#endif
 
    DEBUG_CONVTOLOWER(dprintf("ConvToLower: retval 0x%lx\n",
			retval));

    return(retval);
    
    AROS_LIBFUNC_EXIT
} /* ConvToLower */
