/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: getlocalestru.c,v 1.2 2007/04/10 18:33:44 itix Exp $

    Desc: GetLocaleStrU() - Get a builtin system string.
    Lang: english
*/

/* ---- locale.library/UCS4_GetLocaleStr ----
 *
 *   NAME   
 *        UCS4_GetLocaleStr -- get a system standard string from a locale (V51)
 *
 *   SYNOPSIS
 *        string = UCS4_GetLocaleStr(locale, stringNum);
 *
 *        CONST_WSTRPTR UCS4_GetLocaleStr(struct Locale *, ULONG);
 *
 *   FUNCTION
 *        This function will return a system standard unicode string from
 *        the current Locale.
 *
 *   INPUTS
 *        locale      - The current locale.
 *        stringNum   - The number of the string to get a pointer to.
 *                      See the include file <libraries/locale.h>
 *                      for a list of possible values.
 *
 *   RESULT
 *        A pointer to a NULL-terminated wide string, or NULL if the string
 *        requested was unknown. The returned string is READ-ONLY and
 *        is valid only as long as the Locale remains open.
 *
 *        Unicode characters in the returned strings are always in the native
 *        byte order.
 *
 *
 *   NOTES
 *        If the current locale does not support unicode this function returns
 *        English strings.
 *
 *   SEE ALSO
 *        GetLocaleStr()
 *
 */

#include <exec/types.h>
#include <proto/exec.h>
#include "locale_intern.h"
#include <aros/asmcall.h>

CONST_WSTRPTR GetLocaleStrU(struct Locale *locale, ULONG stringNum, struct LocaleBase *LocaleBase)
{
	CONST_WSTRPTR (*getlocalestru)(ULONG, struct LocaleBase *);

	getlocalestru = IntL(locale)->il_LanguageFunctions[LF_GETLOCALESTRU];

	return getlocalestru(stringNum, LocaleBase);
}
